<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>osd::DisPlayModeApplet</name>
    <message>
        <source>Duplicate</source>
        <translation>Duplicar</translation>
    </message>
    <message>
        <source>Extend</source>
        <translation>Estender</translation>
    </message>
    <message>
        <source>Only on %1</source>
        <translation>Somente em %1</translation>
    </message>
</context>
</TS>